library(mockery)
library(tibble)

cookies <- tibble::tibble(
  domain = "#HttpOnly_example.org",
  name = "JSESSIONID",
  value = "abcde"
)
handle <- httr::handle(url = "http://example.org:8080")
connection <- methods::new("ArmadilloConnection",
  name = "name",
  handle = handle,
  user = "admin",
  cookies = cookies
)
